@@ -9,21 +9,26 @@ from xml.sax.handler import feature_namespaces
 from xml.sax.handler import ContentHandler
 from StringIO import StringIO
 
+
 class XMLImportError(Exception):
     pass
 
+
 class NotAllowedError(XMLImportError):
     """Something found that is not allowed.
     """
 
+
 class ElementNotAllowedError(NotAllowedError):
     """Element is found that is not allowed.
     """
 
+
 class TextNotAllowedError(NotAllowedError):
     """Text is found that is not allowed.
     """
-    
+
+
 class BaseSettings(object):
     """Base class of settings sent to the handlers.
 
@@ -32,20 +37,22 @@ class BaseSettings(object):
     def __init__(self, ignore_not_allowed=False, import_filter_factory=None):
         self._ignore_not_allowed = ignore_not_allowed
         self._import_filter_factory = import_filter_factory
-        
+
     def ignoreNotAllowed(self):
         return self._ignore_not_allowed
-       
+
     def getImportFilterFactory(self):
         return self._import_filter_factory
 
+
 # null settings contains the default settings
 NULL_SETTINGS = BaseSettings()
 IGNORE_SETTINGS = BaseSettings(ignore_not_allowed=True)
 
-class MappingStack:
+
+class MappingStack(object):
     """A runtime stack for content handlers
-    
+
     It wraps a Importer mapping and provides overrides.
     """
 
@@ -54,7 +61,7 @@ class MappingStack:
         """
         self.__mapping = mapping
         self.__stack = []
-    
+
     def getHandler(self, element):
         """Retrieve handler for a particular element (ns, name) tuple.
         """
@@ -68,7 +75,7 @@ class MappingStack:
 
         Overrides provide new handlers for (existing) elements.
         Until popped again, the new handlers are used.
-       
+
         overrides - mapping with key is element tuple (ns, name),
                     value is handler instance.
         """
@@ -83,7 +90,7 @@ class MappingStack:
         for element in keys:
             self.pushOverride(element, handler)
         self.__stack.append(keys)
-        
+
     def popOverrides(self):
         """Pop overrides.
 
@@ -104,9 +111,10 @@ class MappingStack:
             del self.__mapping[element]
 
 
-class Importer:
+class Importer(object):
     """A SAX based importer.
     """
+
     def __init__(self, handler_map=None):
         """Create an importer.
 
@@ -116,7 +124,7 @@ class Importer:
         self._mapping = {}
         if handler_map is not None:
             self.addHandlerMap(handler_map)
-        
+
     # MANIPULATORS
 
     def getMapping(self):
@@ -133,13 +141,13 @@ class Importer:
 
     def registerHandler(self, element, handler_factory):
         """Register a handler for a single element.
-        
+
         element - an xml element name
         handler_factory - the class of the SAX event handler for it
                            (subclass of BaseHandler)
         """
         self._mapping[element] = [handler_factory]
-            
+
     def importHandler(self, settings=NULL_SETTINGS, result=None, info=None):
         """Get import handler.
 
@@ -150,7 +158,7 @@ class Importer:
         result - initial result object to attach everything to (optional)
 
         Does not apply any import filters.
-        
+
         returns handler object. handler.result() gives the end result, or pass
         initial result yourself.
         """
@@ -169,7 +177,7 @@ class Importer:
         result - initial result object to attach everything to (optional)
 
         Applies an import filter if one is specified in the settings.
-        
+
         returns top result object
         """
         handler = self.importHandler(settings, result, info)
@@ -198,13 +206,14 @@ class Importer:
         """
         f = StringIO(s)
         return self.importFromFile(f, settings, result, info)
-   
+
+
 class _SaxImportHandler(ContentHandler):
     """Receives the SAX events and dispatches them to sub handlers.
-    
+
     The importer is a ImporterMappingStack object
     """
-    
+
     def __init__(self, mapping_stack, settings=None, result=None, info=None):
         self.__mapping_stack = mapping_stack
         # top of the handler stack is handler which ignores any events,
@@ -216,15 +225,15 @@ class _SaxImportHandler(ContentHandler):
         self._settings = settings
         self._locator = DummyLocator()
         self._info = info
-        
+
     def setDocumentLocator(self, locator):
         self._locator = locator
-        
+
     def startDocument(self):
-        pass 
-    
+        pass
+
     def endDocument(self):
-        pass    
+        pass
 
     def startElementNS(self, name, qname, attrs):
         parent_handler = self._handler_stack[-1]
@@ -255,8 +264,8 @@ class _SaxImportHandler(ContentHandler):
             self.__mapping_stack.pushOverrides(handler.getOverrides())
             self._handler_stack.append(handler)
             self._depth_stack.append(self._depth)
-        
-        handler.startElementNS(name, qname, attrs)    
+
+        handler.startElementNS(name, qname, attrs)
         self._depth += 1
 
     def endElementNS(self, name, qname):
@@ -270,18 +279,18 @@ class _SaxImportHandler(ContentHandler):
             parent_handler = self._handler_stack[-1]
         else:
             parent_handler = handler
-    
+
         if parent_handler._checkElementAllowed(name):
             handler.endElementNS(name, qname)
-    
+
     def characters(self, chrs):
         handler = self._handler_stack[-1]
         if handler._checkTextAllowed(chrs):
             handler.characters(chrs)
-        
+
     def getInfo(self):
         return self._info
-    
+
     def getSettings(self):
         return self._settings
 
@@ -292,34 +301,37 @@ class _SaxImportHandler(ContentHandler):
         be the one we need, otherwise get result of outer element.
         """
         return self._outer_result or self._result
-    
-class DummyLocator:
+
+
+class DummyLocator(object):
     """A dummy locator which is used if no document locator is available.
     """
+
     def getColumnNumber(self):
-        """Return the column number where the current event ends. 
+        """Return the column number where the current event ends.
         """
         return None
-        
+
     def getLineNumber(self):
-        """Return the line number where the current event ends. 
+        """Return the line number where the current event ends.
         """
         return None
 
     def getPublicId(self):
-        """Return the public identifier for the current event. 
+        """Return the public identifier for the current event.
         """
         return None
 
     def getSystemId(self):
-        """Return the system identifier for the current event. 
+        """Return the system identifier for the current event.
         """
         return None
-    
+
+
 class BaseHandler(object):
     """Base class of all handlers.
 
-    This should be subclassed to implement your own handlers. 
+    This should be subclassed to implement your own handlers.
     """
     def __init__(self, parent, parent_handler,
                  settings=NULL_SETTINGS, info=None):
@@ -342,7 +354,7 @@ class BaseHandler(object):
         """Sets the result data for this handler
         """
         self._result = result
-    
+
     def setData(self, key, value):
         """Many sub-elements with text-data use this to pass that data to
         their parent (self.parentHandler().setData(foo, bar))
@@ -351,12 +363,12 @@ class BaseHandler(object):
 
     def setDocumentLocator(self, locator):
         self._locator = locator
-        
+
     # ACCESSORS
 
     def getInfo(self):
         return self._info
-    
+
     def getData(self, key):
         if self._data.has_key(key):
             return self._data[key]
@@ -364,17 +376,17 @@ class BaseHandler(object):
 
     def getDocumentLocator(self):
          return self._locator
-            
+
     def parentHandler(self):
         """Gets the parent handler
         """
         return self._parent_handler
-    
+
     def parent(self):
-        """Gets the parent 
+        """Gets the parent
         """
         return self._parent
-    
+
     def result(self):
         """Gets the result data for this handler or the result data of the
         parent, if this handler didn't set any
@@ -406,12 +418,12 @@ class BaseHandler(object):
         raise TextNotAllowedError,\
               "Element %s in namespace %s is not allowed here" % (
             name[1], name[0])
-    
-    # OVERRIDES 
-    
+
+    # OVERRIDES
+
     def startElementNS(self, name, qname, attrs):
         pass
-    
+
     def endElementNS(self, name, qname):
         pass
 
@@ -419,7 +431,7 @@ class BaseHandler(object):
         pass
 
     def getOverrides(self):
-        """Returns a dictionary of overridden handlers for xml elements. 
+        """Returns a dictionary of overridden handlers for xml elements.
         (The handlers override any registered handler for that element, but
         getOverrides() can be used to 'override' tags that aren't
         registered.)
@@ -428,7 +440,7 @@ class BaseHandler(object):
 
     def isElementAllowed(self, name):
         """Returns True if element is to be processed at all by handler.
-        
+
         name - ns, name tuple.
 
         Can be overridden in subclass. If it returns False, element is
@@ -447,10 +459,11 @@ class BaseHandler(object):
         importer.
         """
         return True
-    
+
+
 class IgnoringHandler(BaseHandler):
     """A handler that ignores any incoming events that cannot be handled.
     """
     pass
 
-    
+
